#ifndef BISON_Y_TAB_H
# define BISON_Y_TAB_H

#ifndef YYSTYPE
typedef union {
  Code * code;
  __String * str;
  int zahl;
  Knoten * knoten;
  DefKnoten * defknoten;
  ListenKnoten * listenknoten;
  WortKnoten * wortknoten;
  Variable * variable;
  int variablen_ort[2];
} yystype;
# define YYSTYPE yystype
# define YYSTYPE_IS_TRIVIAL 1
#endif
# define	IF_PREC	257
# define	ELSE_TOK	258
# define	OR_TOK	259
# define	AND_TOK	260
# define	EQ_TOK	261
# define	NE_TOK	262
# define	GE_TOK	263
# define	LE_TOK	264
# define	INTERVALL_PREC	265
# define	NEG_PREC	266
# define	INCLUDE_TOK	267
# define	BEGIN_CODE_TOK	268
# define	END_CODE_TOK	269
# define	SWITCH_TOK	270
# define	IF_TOK	271
# define	BIS_TOK	272
# define	VAR_TOK	273
# define	BUSY_TOK	274
# define	ADD_TOK	275
# define	SUB_TOK	276
# define	MUL_TOK	277
# define	DIV_TOK	278
# define	MOD_TOK	279
# define	RND_TOK	280
# define	GGT_TOK	281
# define	BONUS_TOK	282
# define	MESSAGE_TOK	283
# define	EXPLODE_TOK	284
# define	REINWORT_TOK	285
# define	WORT_TOK	286
# define	NACHBAR8_TOK	287
# define	NACHBAR6_TOK	288
# define	NULLEINS_TOK	289
# define	ZAHL_TOK	290
# define	HALBZAHL_TOK	291
# define	BUCHSTABE_TOK	292
# define	PFEIL_TOK	293


#endif /* not BISON_Y_TAB_H */
